@@ -42,6 +42,22 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
                                colid = params_sleep[["colid"]],
                                meta.sleep.folder = meta.sleep.folder,
                                desiredtz = params_general[["desiredtz"]])
+      
+      if (params_sleep[["sleepwindowType"]] == "SPT" && length(logs_diaries$bedlog) > 0 &&
+          length(logs_diaries$sleeplog) == 0) {
+        stop(paste0("The sleep diary as provided only appears to have time indicators",
+                    " for time in bed and not for the Sleep Period Time window, while",
+                    " parameter sleepwindowType is set to SPT (default). Either change sleepwindowType to",
+                    " \"TimeInBed\" or change your sleep diary column names for sleep timing",
+                    " to \"wakeup\" and \"sleeponset\"."), call. = FALSE)
+      } else if (params_sleep[["sleepwindowType"]] == "TimeInBed" && length(logs_diaries$bedlog) == 0 &&
+                 length(logs_diaries$sleeplog) > 0) {
+        stop(paste0("The sleep diary as provided only appears to have time indicators",
+                    " for SPT and not for the Time in Bed, while",
+                    " parameter sleepwindowType is set to TimeInBed. Either change sleepwindowType to",
+                    " \"SPT\" or change your sleep diary column names for sleep timing",
+                    " to \"outbed\" and \"inbed\"."), call. = FALSE)
+      }
       save(logs_diaries, file = sleeplogRDataFile)
     } else {
       load(file = sleeplogRDataFile)
@@ -80,7 +96,7 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
                            "number_sib_wakinghours", "duration_sib_wakinghours_atleast15min",
                            "sleeponset_ts", "wakeup_ts", "guider_onset_ts",  "guider_wakeup_ts",
                            "sleeplatency", "sleepefficiency", "page", "daysleeper", "weekday", "calendar_date",
-                           "filename", "cleaningcode", "sleeplog_used", "sleeplog_ID", "acc_available", "guider", "SleepRegularityIndex", "SriFractionValid",
+                           "filename", "cleaningcode", "sleeplog_used", "sleeplog_ID", "acc_available", "guider", "SleepRegularityIndex1", "SriFractionValid",
                            "longitudinal_axis") #
   
   
@@ -286,9 +302,10 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
           # go through the nights get default onset and wake (based on sleeplog or on heuristic
           # algorithms) def.noc.sleep is an input argument the GGIR user can use to specify what
           # detection strategy is used in the absense of a sleep diary
-          if (length(params_sleep[["def.noc.sleep"]]) == 0 ||
-              length(SPTE_start) == 0 ||
-              length(SPTE_start[which(is.na(SPTE_start) == FALSE)]) == 0) {
+          if ((length(params_sleep[["def.noc.sleep"]]) == 0 ||
+               length(SPTE_start) == 0 ||
+               length(SPTE_start[which(is.na(SPTE_start) == FALSE)]) == 0) &&
+              length(params_sleep[["def.noc.sleep"]]) != 2) {
             # use L5+/-6hr algorithm if SPTE fails OR if the user explicitely asks for it (length
             # zero argument)
             guider = "notavailable"
@@ -300,7 +317,6 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
               # This should never happen, but just as a final backup
               defaultGuiderOnset = 21
               defaultGuiderWake = 31
-              warning("Guider not identified in ID ", accid, ", falling back on 9pm-7am window", call. = FALSE)
             }
             defaultGuider = guider
           } else if ((length(params_sleep[["def.noc.sleep"]]) == 1 ||
@@ -634,7 +650,7 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
                 # Classify as being part of the guider window or not
                 for (evi in 1:nrow(spo)) {
                   if (spo$start[evi] < GuiderWake && spo$end[evi] > GuiderOnset) {
-                    if (params_sleep[["sleepwindowType"]] == "TimeInBed" &&
+                    if ((params_sleep[["sleepwindowType"]] == "TimeInBed" || guider == "markerbutton") &&
                         sum(params_sleep[["sib_must_fully_overlap_with_TimeInBed"]]) != 0) {
                       if (all(params_sleep[["sib_must_fully_overlap_with_TimeInBed"]]) &&
                           spo$start[evi] > GuiderOnset && spo$end[evi] < GuiderWake) {
@@ -968,9 +984,10 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
                   #----------------------------------------------
                   nightsummary[sumi, 23] = tmp1  #guider_onset_ts
                   nightsummary[sumi, 24] = tmp4  #guider_wake_ts
-                  if (params_sleep[["sleepwindowType"]] == "TimeInBed") {
-                    # If guider is a sleeplog and if the sleeplog recorded time in bed then
-                    # calculate: sleep latency:
+                  if (params_sleep[["sleepwindowType"]] == "TimeInBed" || guider == "markerbutton") {
+                    # If guider is a sleeplog and if the sleeplog recorded time in bed or a marker button
+                    # then calculate:
+                    # sleep latency:
                     nightsummary[sumi, 25] = round(nightsummary[sumi, 3] - nightsummary[sumi, 7],
                                                    digits = 7)  #sleeponset - guider_onset
                     # sleep efficiency:
@@ -1133,7 +1150,8 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
           }
           sumi = sumi + 1
         }
-        if (params_sleep[["sleepwindowType"]] != "TimeInBed") {
+        if (params_sleep[["sleepwindowType"]] != "TimeInBed" &&
+            params_sleep[["consider_marker_button"]] == FALSE) {
           nightsummary = nightsummary[, which(colnames(nightsummary) %in% c("sleeplatency", "sleepefficiency") ==
                                                 FALSE)]
         }
