@@ -82,8 +82,23 @@ g.sibreport = function(ts, ID, epochlength, logs_diaries=c(), desiredtz="") {
                 timestamps = as.POSIXlt(paste0(date, " ", times), tz = desiredtz)
                 hour = as.numeric(format(timestamps, "%H"))
                 if (!is.null(firstDate)) {
-                  # sleeplog start and/or ending after midnight
+                  # date on which night start is default
+                  # time before noon are likely to occur on the next day
                   AM = which(hour <= 12)
+                  
+                  # When wake is after noon and before 6pm
+                  # then it is a daysleeper and the wake up time
+                  # is also likely to be on the next day
+                  if (hour[2] > 12 & hour[2] <= 18) { # daysleeper
+                    AM = c(AM, 2)
+                  }
+                  # however, wake can never be after onset when wake is at AM
+                  # 11am - 9am, simply means that person apparently reported to
+                  # sleep from 11am to 9am next day. Most likely a mistake in the
+                  # diary, but not to be interpretted as 9am-11am
+                  if (hour[1] > hour[2] && 1 %in% AM) {
+                    AM = AM[which(AM != 1)]
+                  }
                   if (length(AM) > 0) {
                     timestamps[AM] = as.POSIXlt(paste0(date + 1, " ", times[AM]), tz = desiredtz)
                   }
